Division class

Set col and offset

Constructors

Division({int colXS = 12, int? colS, int? colM, int? colL, int? colXL, int offsetXS = 0, int offsetS = 0, int offsetM = 0, int offsetL = 0, int offsetXL = 0})
const

Properties

colL → int?
Large screen 897.0 to 1232.0
final
colM → int?
Medium screen 596.0 to 897.0
final
colS → int?
Small screen 375.0 to 596.0
final
colXL → int?
Very Large screen > 1232.0
final
colXS → int
Extra Small screen < 375.0
final
hashCode → int
The hash code for this object.
no setterinherited
offsetL → int
input range 0 -12
final
offsetM → int
input range 0 -12
final
offsetS → int
input range 0 -12
final
offsetXL → int
input range 0 -12
final
offsetXS → int
input range 0 -12
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widthL → int
Returns the width of the column for the given screen size
no setter
widthM → int
Returns the width of the column for the given screen size
no setter
widthS → int
Returns the width of the column for the given screen size
no setter
widthXL → int
Returns the width of the column for the given screen size
no setter

Methods

copyWith({int? colXS, int? colS, int? colM, int? colL, int? colXL, int? offsetXS, int? offsetS, int? offsetM, int? offsetL, int? offsetXL}) → Division
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited